'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports.default = reducer;
exports.getState = getState;
exports.getWs = getWs;
exports.getWsAvailGroups = getWsAvailGroups;

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var ON_CTP3_MON_SUBSCRIBE = exports.ON_CTP3_MON_SUBSCRIBE = 'ON_CTP3_MON_SUBSCRIBE';
var ON_CTP3_MON_UNSUBSCRIBE = exports.ON_CTP3_MON_UNSUBSCRIBE = 'ON_CTP3_MON_UNSUBSCRIBE';
var ON_CTP3_MON_ZMQ_ADD_GROUP = exports.ON_CTP3_MON_ZMQ_ADD_GROUP = 'ON_CTP3_MON_ZMQ_ADD_GROUP';
var ON_CTP3_MON_ZMQ_REMOVE_GROUP = exports.ON_CTP3_MON_ZMQ_REMOVE_GROUP = 'ON_CTP3_MON_ZMQ_REMOVE_GROUP';

var ctp3Sub = exports.ctp3Sub = function ctp3Sub(name, ws, zmq_sock) {
    return {
        type: ON_CTP3_MON_SUBSCRIBE,
        name: name,
        ws: ws,
        zmq_sock: zmq_sock
    };
};

var ctp3UnSub = exports.ctp3UnSub = function ctp3UnSub(ws) {
    return {
        type: ON_CTP3_MON_UNSUBSCRIBE,
        ws: ws
    };
};

var ctp3ZmqSubAdd = exports.ctp3ZmqSubAdd = function ctp3ZmqSubAdd(name) {
    return {
        type: ON_CTP3_MON_ZMQ_ADD_GROUP,
        name: name
    };
};

var ctp3ZmqSubRemove = exports.ctp3ZmqSubRemove = function ctp3ZmqSubRemove(name) {
    return {
        type: ON_CTP3_MON_ZMQ_REMOVE_GROUP,
        name: name
    };
};

var initialState = {
    wsClients: {},
    availMonGroups: []
};

// reducer
function reducer() {
    var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : initialState;
    var action = arguments[1];

    switch (action.type) {
        case ON_CTP3_MON_SUBSCRIBE:
            var zmqUnSub = action.zmq_sock.zmq$[action.name].subscribe(function (data) {
                action.ws.send(JSON.stringify(data));
            });
            return _extends({}, state, { wsClients: _extends({}, state.wsClients, _defineProperty({}, action.ws.id, { name: action.name, zmqUnSub: zmqUnSub })) });
        case ON_CTP3_MON_UNSUBSCRIBE:
            if (state.wsClients[action.ws.id] === undefined) {
                return state;
            }
            var clients = _extends({}, state.wsClients);
            clients[action.ws.id].zmqUnSub.unsubscribe();
            delete clients[action.ws.id];
            return _extends({}, state, { wsClients: clients });
        case ON_CTP3_MON_ZMQ_ADD_GROUP:
            if (!state.availMonGroups.includes(action.name)) return _extends({}, state, { availMonGroups: [].concat(_toConsumableArray(state.availMonGroups), [action.name]) });
            return state;
        case ON_CTP3_MON_ZMQ_REMOVE_GROUP:
            if (state.availMonGroups.includes(action.name)) return _extends({}, state, { availMonGroups: state.availMonGroups.filter(function (item) {
                    return item !== action.name;
                }) });
            return state;
        default:
            return state;
    }
}

// selectors 
function getState(store) {
    return store.getState().ctp3Mon;
}

function getWs(store) {
    return JSON.stringify({
        type: "ctp3Mon",
        payload: getState(store)
    });
}

function getWsAvailGroups(store) {
    return JSON.stringify({
        type: "ctp3MonGroups",
        payload: getState(store).availMonGroups
    });
}