'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _uuid = require('uuid');

var _uuid2 = _interopRequireDefault(_uuid);

var _http = require('http');

var _http2 = _interopRequireDefault(_http);

var _https = require('https');

var _https2 = _interopRequireDefault(_https);

var _express = require('express');

var _express2 = _interopRequireDefault(_express);

var _bodyParser = require('body-parser');

var _bodyParser2 = _interopRequireDefault(_bodyParser);

var _cors = require('cors');

var _cors2 = _interopRequireDefault(_cors);

var _ws = require('ws');

var _ws2 = _interopRequireDefault(_ws);

var _zmq = require('./zmq');

var _zmq2 = _interopRequireDefault(_zmq);

var _store = require('./redux/store');

var _store2 = _interopRequireDefault(_store);

var _appInfo = require('./redux/modules/appInfo');

var appInfo = _interopRequireWildcard(_appInfo);

var _ctp3Mon = require('./redux/modules/ctp3Mon');

var ctp3Mon = _interopRequireWildcard(_ctp3Mon);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var server = (0, _express2.default)();

// redux

var useHttps = false;

server.use(_bodyParser2.default.json());
server.use(_bodyParser2.default.urlencoded({ extended: false }));
server.use((0, _cors2.default)({ allowedOrigins: '*' }));

if (useHttps) {
    var privateKey = _fs2.default.readFileSync('ssl/server.key', 'utf8');
    var certificate = _fs2.default.readFileSync('ssl/server.crt', 'utf8');
    var credentials = { key: privateKey, cert: certificate };
    server.server = _https2.default.createServer(credentials, server);
    server.set('port', process.env.PORT || 8443);
} else {
    server.server = _http2.default.createServer(server);
    server.set('port', process.env.PORT || 8442);
}

server.wss = new _ws2.default.Server({ server: server.server });

server.wss.broadcast = function broadcast(data) {
    server.wss.clients.forEach(function each(client) {
        if (client.readyState === _ws2.default.OPEN) {
            client.send(data);
        }
    });
};

server.wss.on('connection', function (ws) {

    _store2.default.dispatch(appInfo.wsEnter());
    server.wss.broadcast(appInfo.getWs(_store2.default));
    ws.send(ctp3Mon.getWsAvailGroups(_store2.default));

    // let zmq_sub_type = 'monbusy';

    // generate id of websocket
    ws.id = _uuid2.default.v4();

    var nclients = Array.from(server.wss.clients).length;
    console.log('[' + nclients + '] User ' + ws.id + ' was connected');

    ws.on('message', function (msg) {
        console.log('received: %s', msg);
        var m = JSON.parse(msg);
        if (m.type === undefined || m.name === undefined) return;

        switch (m.type) {
            case 'sub':
                _store2.default.dispatch(ctp3Mon.ctp3Sub(m.name, ws, _zmq2.default));
                break;
            case 'unsub':
                _store2.default.dispatch(ctp3Mon.ctp3UnSub(ws));
                break;
            default:
                return;
        }
    });

    ws.on('close', function () {
        _store2.default.dispatch(appInfo.wsExit());
        server.wss.broadcast(appInfo.getWs(_store2.default));

        var nclients = Array.from(server.wss.clients).length;
        console.log('[' + nclients + '] User ' + ws.id + ' was disconnected');

        // unsubscribe all subscriptions (we have only one per ws now)
        _store2.default.dispatch(ctp3Mon.ctp3UnSub(ws));
    });

    ws.on('error', function () {
        return console.log('errored');
    });
});

server.get('*', function (req, res) {
    res.sendFile(__dirname + '/index.html');
});

server.server.listen(server.get('port'), function () {
    return console.log('Http' + (useHttps ? 's' : '') + ' is listening on port ' + server.get('port'));
});

exports.default = server;